==> xlnl-3.4.0.tar.gz: xlnl-3.4.0/src/WinPos.cpp <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: WinPos.cpp,v 1.14 2009/03/13 14:54:38 bowkenken Exp $
***************************************************************/

////////////////////////////////////////////////////////////////
// ɥκɸȥδ
////////////////////////////////////////////////////////////////

#include "gmain.h"

#include "WinPos.h"
#include "GlobalVar.h"

////////////////////////////////////////////////////////////////
// 󥹥ȥ饯
////////////////////////////////////////////////////////////////

WinPos::WinPos()
{
	flagDraw = false;
	x = 0;
	y = 0;
	w = -1;
	h = -1;
}

////////////////////////////////////////////////////////////////
// ǥȥ饯
////////////////////////////////////////////////////////////////

WinPos::~WinPos()
{
}

////////////////////////////////////////////////////////////////
// ɥ֤
// win_kind_t kind : ɥμ
// return : ɥ
////////////////////////////////////////////////////////////////

void *WinPos::getWin( win_kind_t kind )
{
#ifdef D_WS
//@@@
#endif // D_WS

#ifdef D_GTK
	switch( kind ){
	case WIN_KIND_NULL:
		break;
	case WIN_KIND_MAP:
		return gMapWin;
	case WIN_KIND_SEL_CONF:
		return gSelConf.mSelConfWin;
	case WIN_KIND_MENU:
		return gGuiMenu.mMenuWin;
	case WIN_KIND_MESSAGE:
		return gGuiMessage.mMessageWin;
	case WIN_KIND_STAT:
		return gGuiStat.mStatWin;
	case WIN_KIND_STAT_1:
	case WIN_KIND_STAT_2:
	case WIN_KIND_STAT_3:
	case WIN_KIND_STAT_4:
	case WIN_KIND_STAT_5:
	case WIN_KIND_STAT_6:
		break;
	case WIN_KIND_INPUT_NUM:
		return gGuiNum.mNumWin;
	case WIN_KIND_INPUT_STRING:
		return gGuiInpStr.mWin;
	case WIN_KIND_WORDS:
		return gGuiWords.mWordsWin;
	case WIN_KIND_REPLAY:
		return gGuiReplay.mReplayWin;
	case WIN_KIND_CLASS_EDIT:
		return gGuiClassEdit.mClassEditWin;
	case WIN_KIND_SKILL_EDIT:
		return gGuiSkillEdit.mSkillEditWin;
	case WIN_KIND_CHR_SHEET:
		return gGuiChrSheet.mChrSheetWin;
	case WIN_KIND_MAX_N:
		break;
	}
#endif //D_GTK

#ifdef D_MFC
	switch( kind ){
	case WIN_KIND_NULL:
		break;
	case WIN_KIND_MAP:
		return theApp.m_pMainWnd;
	case WIN_KIND_SEL_CONF:
		return gSelConf.mDlg;
	case WIN_KIND_MENU:
		return gGuiMenu.mMenuWin;
	case WIN_KIND_MESSAGE:
		return gGuiMessage.mMessageWin;
	case WIN_KIND_STAT:
		return gGuiStat.mStatWin;
	case WIN_KIND_STAT_1:
	case WIN_KIND_STAT_2:
	case WIN_KIND_STAT_3:
	case WIN_KIND_STAT_4:
	case WIN_KIND_STAT_5:
	case WIN_KIND_STAT_6:
		break;
	case WIN_KIND_INPUT_NUM:
		return gGuiNum.mNumWin;
	case WIN_KIND_INPUT_STRING:
		return gGuiInpStr.mInpStrWin;
	case WIN_KIND_WORDS:
		return gGuiWords.mWordsWin;
	case WIN_KIND_REPLAY:
		return gGuiReplay.mReplayWin;
	case WIN_KIND_CLASS_EDIT:
		return gGuiClassEdit.mClassEditWin;
	case WIN_KIND_CHR_SHEET:
		return gGuiChrSheet.mChrSheetWin;
	case WIN_KIND_MAX_N:
		break;
	}
#endif //D_MFC

	return NULL;
}

////////////////////////////////////////////////////////////////
// ɥκɸ
// win_kind_t kind : ɥμ
// long *px : X ɸ
// long *py : Y ɸ
// long *pw : 
// long *ph : ⤵
////////////////////////////////////////////////////////////////

void WinPos::set(
	win_kind_t kind,
	long *px, long *py,
	long *pw, long *ph )
{
	if( px != NULL )
		x = *px;
	if( py != NULL )
		y = *py;
	if( pw != NULL )
		w = *pw;
	if( ph != NULL )
		h = *ph;

	if( flagDraw )
		draw( kind );
}

////////////////////////////////////////////////////////////////
// ɥκɸμ
// win_kind_t kind : ɥμ
// long *px : X ɸ
// long *py : Y ɸ
// long *pw : 
// long *ph : ⤵
////////////////////////////////////////////////////////////////

void WinPos::get(
	win_kind_t kind,
	long *px, long *py,
	long *pw, long *ph )
{
	void *pWin = getWin( kind );

	if( (pWin != NULL) && flagDraw ){
#ifdef D_WS
//@@@
#endif // D_WS

#ifdef D_GTK
		gint gx, gy, gw, gh;
		gint bgnX, bgnY, endX, endY;

		GdkWindow *win = GTK_WIDGET( pWin )->window;

		// ɸ

		gdk_window_get_position( win, &gx, &gy );
		gdk_window_get_root_origin( win, &bgnX, &bgnY );
		gdk_window_get_origin( win, &endX, &endY );

		gx -= endX - bgnX;
		gy -= endY - bgnY;

		// 

		gdk_window_get_size( win, &gw, &gh );

		// 

		x = gx;
		y = gy;
		w = gw;
		h = gh;
#endif //D_GTK

#ifdef D_MFC
		CRect rect;
		((CWnd *)pWin)->GetWindowRect( &rect );

		x = rect.left;
		y = rect.top;
		w = rect.Width();
		h = rect.Height();
#endif //D_MFC
	}

	if( px != NULL )
		*px = x;
	if( py != NULL )
		*py = y;
	if( pw != NULL )
		*pw = w;
	if( ph != NULL )
		*ph = h;
}

////////////////////////////////////////////////////////////////
// ɥɽ
// win_kind_t kind : ɥμ
////////////////////////////////////////////////////////////////

void WinPos::draw( win_kind_t kind, bool flagDlg )
{
	void *pWin = getWin( kind );
	if( pWin == NULL )
		return;

#ifdef D_WS
	pWin->setVisible( true );
#endif // D_WS

#ifdef D_GTK
	gtk_widget_show( GTK_WIDGET( pWin ) );

	gtk_widget_set_uposition( GTK_WIDGET( pWin ), x, y );
	GTK_WIDGET( pWin )->allocation.width = w;
	GTK_WIDGET( pWin )->allocation.height = h;
//@@@	gtk_widget_set_size_request( GTK_WIDGET( pWin ), w, h );

	gdk_window_raise( GTK_WIDGET( pWin )->window );
#endif //D_GTK

#ifdef D_MFC
	if( flagDlg ){
		CRect rect;
		((CWnd *)pWin)->GetWindowRect( &rect );

		w = rect.Width();
		h = rect.Height();

		if( (w > 0) && (h > 0) )
			((CDialog *)pWin)->MoveWindow( x, y, w, h );
	} else {
		((CWnd *)pWin)->ShowWindow( SW_SHOW );
		if( (w > 0) && (h > 0) )
			((CWnd *)pWin)->MoveWindow( x, y, w, h );
		((CWnd *)pWin)->BringWindowToTop();
		((CWnd *)pWin)->UpdateWindow();
	}
#endif //D_MFC

	flagDraw = true;
}

////////////////////////////////////////////////////////////////
// ɥĤ
// win_kind_t kind : ɥμ
////////////////////////////////////////////////////////////////

void WinPos::wipe( win_kind_t kind, bool flagDlg )
{
	void *pWin = getWin( kind );
	if( pWin == NULL )
		return;

#ifdef D_WS
//@@@
	pWin->setVisible( false );
#endif // D_WS

#ifdef D_GTK
	gint gx, gy, gw, gh;
	gint bgnX, bgnY, endX, endY;

	GdkWindow *win = GTK_WIDGET( pWin )->window;

	// ɸ

	gdk_window_get_position( win, &gx, &gy );
	gdk_window_get_root_origin( win, &bgnX, &bgnY );
	gdk_window_get_origin( win, &endX, &endY );

	gx -= endX - bgnX;
	gy -= endY - bgnY;

	// 

	gdk_window_get_size( win, &gw, &gh );

	// 

	x = gx;
	y = gy;
	w = gw;
	h = gh;

	//

	gtk_widget_hide( GTK_WIDGET( pWin ) );
#endif //D_GTK

#ifdef D_MFC
	CRect rect;
	((CWnd *)pWin)->GetWindowRect( &rect );

	x = rect.left;
	y = rect.top;
	w = rect.Width();
	h = rect.Height();

	if( !flagDlg )
		((CWnd *)pWin)->ShowWindow( SW_HIDE );
#endif //D_MFC

	flagDraw = false;
}

==> xlnl-3.4.1.tar.gz: xlnl-3.4.1/src/WinPos.cpp <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: WinPos.cpp,v 1.14 2009/03/13 14:54:38 bowkenken Exp $
***************************************************************/

////////////////////////////////////////////////////////////////
// ɥκɸȥδ
////////////////////////////////////////////////////////////////

#include "gmain.h"

#include "WinPos.h"
#include "GlobalVar.h"

////////////////////////////////////////////////////////////////
// 󥹥ȥ饯
////////////////////////////////////////////////////////////////

WinPos::WinPos()
{
	flagDraw = false;
	x = 0;
	y = 0;
	w = -1;
	h = -1;
}

////////////////////////////////////////////////////////////////
// ǥȥ饯
////////////////////////////////////////////////////////////////

WinPos::~WinPos()
{
}

////////////////////////////////////////////////////////////////
// ɥ֤
// win_kind_t kind : ɥμ
// return : ɥ
////////////////////////////////////////////////////////////////

void *WinPos::getWin( win_kind_t kind )
{
#ifdef D_WS
//@@@
#endif // D_WS

#ifdef D_GTK
	switch( kind ){
	case WIN_KIND_NULL:
		break;
	case WIN_KIND_MAP:
		return gMapWin;
	case WIN_KIND_SEL_CONF:
		return gSelConf.mSelConfWin;
	case WIN_KIND_MENU:
		return gGuiMenu.mMenuWin;
	case WIN_KIND_MESSAGE:
		return gGuiMessage.mMessageWin;
	case WIN_KIND_STAT:
		return gGuiStat.mStatWin;
	case WIN_KIND_STAT_1:
	case WIN_KIND_STAT_2:
	case WIN_KIND_STAT_3:
	case WIN_KIND_STAT_4:
	case WIN_KIND_STAT_5:
	case WIN_KIND_STAT_6:
		break;
	case WIN_KIND_INPUT_NUM:
		return gGuiNum.mNumWin;
	case WIN_KIND_INPUT_STRING:
		return gGuiInpStr.mWin;
	case WIN_KIND_WORDS:
		return gGuiWords.mWordsWin;
	case WIN_KIND_REPLAY:
		return gGuiReplay.mReplayWin;
	case WIN_KIND_CLASS_EDIT:
		return gGuiClassEdit.mClassEditWin;
	case WIN_KIND_SKILL_EDIT:
		return gGuiSkillEdit.mSkillEditWin;
	case WIN_KIND_CHR_SHEET:
		return gGuiChrSheet.mChrSheetWin;
	case WIN_KIND_MAX_N:
		break;
	}
#endif //D_GTK

#ifdef D_MFC
	switch( kind ){
	case WIN_KIND_NULL:
		break;
	case WIN_KIND_MAP:
		return theApp.m_pMainWnd;
	case WIN_KIND_SEL_CONF:
		return gSelConf.mDlg;
	case WIN_KIND_MENU:
		return gGuiMenu.mMenuWin;
	case WIN_KIND_MESSAGE:
		return gGuiMessage.mMessageWin;
	case WIN_KIND_STAT:
		return gGuiStat.mStatWin;
	case WIN_KIND_STAT_1:
	case WIN_KIND_STAT_2:
	case WIN_KIND_STAT_3:
	case WIN_KIND_STAT_4:
	case WIN_KIND_STAT_5:
	case WIN_KIND_STAT_6:
		break;
	case WIN_KIND_INPUT_NUM:
		return gGuiNum.mNumWin;
	case WIN_KIND_INPUT_STRING:
		return gGuiInpStr.mInpStrWin;
	case WIN_KIND_WORDS:
		return gGuiWords.mWordsWin;
	case WIN_KIND_REPLAY:
		return gGuiReplay.mReplayWin;
	case WIN_KIND_CLASS_EDIT:
		return gGuiClassEdit.mClassEditWin;
	case WIN_KIND_CHR_SHEET:
		return gGuiChrSheet.mChrSheetWin;
	case WIN_KIND_MAX_N:
		break;
	}
#endif //D_MFC

	return NULL;
}

////////////////////////////////////////////////////////////////
// ɥκɸ
// win_kind_t kind : ɥμ
// long *px : X ɸ
// long *py : Y ɸ
// long *pw : 
// long *ph : ⤵
////////////////////////////////////////////////////////////////

void WinPos::set(
	win_kind_t kind,
	long *px, long *py,
	long *pw, long *ph )
{
	if( px != NULL )
		x = *px;
	if( py != NULL )
		y = *py;
	if( pw != NULL )
		w = *pw;
	if( ph != NULL )
		h = *ph;

	if( flagDraw )
		draw( kind );
}

////////////////////////////////////////////////////////////////
// ɥκɸμ
// win_kind_t kind : ɥμ
// long *px : X ɸ
// long *py : Y ɸ
// long *pw : 
// long *ph : ⤵
////////////////////////////////////////////////////////////////

void WinPos::get(
	win_kind_t kind,
	long *px, long *py,
	long *pw, long *ph )
{
	void *pWin = getWin( kind );

	if( (pWin != NULL) && flagDraw ){
#ifdef D_WS
//@@@
#endif // D_WS

#ifdef D_GTK
		gint gx, gy, gw, gh;
		gint fx, fy, fd;
		gint bgnX, bgnY, endX, endY;

		GdkWindow *win = GTK_WIDGET( pWin )->window;

		// ɸ

		gdk_window_get_position( win, &gx, &gy );
		gdk_window_get_deskrelative_origin( win, &fx, &fy );
		gdk_window_get_root_origin( win, &bgnX, &bgnY );
		gdk_window_get_origin( win, &endX, &endY );

		if( g_flg_gnome )
			fd = 0;
		else
			fd = fx - bgnX;

		gx -= endX - bgnX - fd;
		gy -= endY - bgnY - fd;

		// 

		gdk_window_get_size( win, &gw, &gh );

		// 

		x = gx;
		y = gy;
		w = gw;
		h = gh;
#endif //D_GTK

#ifdef D_MFC
		CRect rect;
		((CWnd *)pWin)->GetWindowRect( &rect );

		x = rect.left;
		y = rect.top;
		w = rect.Width();
		h = rect.Height();
#endif //D_MFC
	}

	if( px != NULL )
		*px = x;
	if( py != NULL )
		*py = y;
	if( pw != NULL )
		*pw = w;
	if( ph != NULL )
		*ph = h;
}

////////////////////////////////////////////////////////////////
// ɥɽ
// win_kind_t kind : ɥμ
////////////////////////////////////////////////////////////////

void WinPos::draw( win_kind_t kind, bool flagDlg )
{
	void *pWin = getWin( kind );
	if( pWin == NULL )
		return;

#ifdef D_WS
	pWin->setVisible( true );
#endif // D_WS

#ifdef D_GTK
	gtk_widget_show( GTK_WIDGET( pWin ) );

	gdk_window_move( GTK_WIDGET( pWin )->window, x, y );

	GTK_WIDGET( pWin )->allocation.width = w;
	GTK_WIDGET( pWin )->allocation.height = h;

	gdk_window_raise( GTK_WIDGET( pWin )->window );
#endif //D_GTK

#ifdef D_MFC
	if( flagDlg ){
		CRect rect;
		((CWnd *)pWin)->GetWindowRect( &rect );

		w = rect.Width();
		h = rect.Height();

		if( (w > 0) && (h > 0) )
			((CDialog *)pWin)->MoveWindow( x, y, w, h );
	} else {
		((CWnd *)pWin)->ShowWindow( SW_SHOW );
		if( (w > 0) && (h > 0) )
			((CWnd *)pWin)->MoveWindow( x, y, w, h );
		((CWnd *)pWin)->BringWindowToTop();
		((CWnd *)pWin)->UpdateWindow();
	}
#endif //D_MFC

	flagDraw = true;
}

////////////////////////////////////////////////////////////////
// ɥĤ
// win_kind_t kind : ɥμ
////////////////////////////////////////////////////////////////

void WinPos::wipe( win_kind_t kind, bool flagDlg )
{
	void *pWin = getWin( kind );
	if( pWin == NULL )
		return;

#ifdef D_WS
//@@@
	pWin->setVisible( false );
#endif // D_WS

#ifdef D_GTK
	gint gx, gy, gw, gh;
	gint bgnX, bgnY, endX, endY;

	GdkWindow *win = GTK_WIDGET( pWin )->window;

	// ɸ

	gdk_window_get_position( win, &gx, &gy );
	gdk_window_get_root_origin( win, &bgnX, &bgnY );
	gdk_window_get_origin( win, &endX, &endY );

	gx -= endX - bgnX;
	gy -= endY - bgnY;

	// 

	gdk_window_get_size( win, &gw, &gh );

	// 

	x = gx;
	y = gy;
	w = gw;
	h = gh;

	//

	gtk_widget_hide( GTK_WIDGET( pWin ) );
#endif //D_GTK

#ifdef D_MFC
	CRect rect;
	((CWnd *)pWin)->GetWindowRect( &rect );

	x = rect.left;
	y = rect.top;
	w = rect.Width();
	h = rect.Height();

	if( !flagDlg )
		((CWnd *)pWin)->ShowWindow( SW_HIDE );
#endif //D_MFC

	flagDraw = false;
}
